# Load the package readxl to import excel data and the package meta to run meta-analyses
library(readxl)
library(meta)


# Change settings so results are rounded to two digits (default is four digits)
settings.meta(digits = 2)





########        Dataset BCG trial        ########
#################################################

# Load dataset "bcgtrial" and store it as dataframe object called "BCG"
BCG = read_excel("bcgtrial.xls")
BCG <- as.data.frame(BCG)

# Check the data structure
str(BCG)


# calculate risk ratios and 95% confidence intervals for each study
BCG$rr <-       (BCG$cases1/BCG$pop1) / (BCG$cases0/BCG$pop0)               # risk ratio

BCG$logrr <-    log(BCG$rr)                                                 # log risk ratio

BCG$selogrr <-  sqrt(1/BCG$cases1 - 1/BCG$pop1 + 1/BCG$cases0 - 1/BCG$pop0) # std error of log risk ratio

BCG$loglci <-   BCG$logrr-1.96*BCG$selogrr                                  # lower bound  95% confidence interval in log scale

BCG$loguci <-   BCG$logrr+1.96*BCG$selogrr                                  # upper bound  95% confidence interval in log scale

BCG$lci <-      exp(BCG$loglci)                                             # lower bound  95% confidence interval

BCG$uci <-      exp(BCG$loguci)                                             # upper bound  95% confidence interval


# Print the results for all study:
BCG[,c("trial", "trialnam", "startyr", "latitude", "rr", "lci", "uci")]




########        Meta-analysis of the effect of BCG on tubercolosis        ########
##################################################################################

# run meta-analysis and store results in object of class meta "ma1"
ma1 = metabin(cases1, pop1, cases0, pop0, data = BCG, 
              studlab = trialnam, sm = "RR")
summary(ma1)

# Create forest plot
forest(ma1, leftcols = c("trialnam","authors"), leftlabs=c("Trial name", "Authors"), 
       just.addcols = "left", rightcols = c("effect", "ci", "w.fixed", "w.random", "startyr", "alloc"), 
       rightlabs = c("Year", "Allocation"), digits.addcols.right = 0)



########        Subgroup analysis        ########
#################################################

# create variable to distinguish USA studies from non-USA studies
BCG$USA <- ifelse(BCG$trial %in% c(1,8,10,11), "USA", "elsewhere")

table(BCG$trialnam, BCG$USA)        # check the results

# create new meta-analysis for subgroup analysis (argument byvar) and store it as "ma2"
ma2 = metabin(cases1, pop1, cases0, pop0, data = BCG, 
              studlab = trialnam, sm = "RR", byvar = USA)

# produce forest plot
forest(ma2, bylab = "")



# produce forest plot with studies sorted by latitude
forest(ma1, leftcols = c("trialnam","authors", "latitude"), just.addcols = "left", sortvar = latitude)



# prouce forest plot with studies sorted by year the trial started
forest(ma1, leftcols = c("trialnam","authors", "startyr"), just.addcols = "left", sortvar = startyr)



# perform subgroup analysis by allocation method
table(BCG$trialnam, BCG$alloc)                    # tabulation of studies and allocation method

ma3 = metabin(cases1, pop1, cases0, pop0, 
              data = BCG, studlab = trialnam, 
              sm = "RR", subgroup = alloc)           # meta-analysis with subgroup analysis by allocation method
summary(ma3)

forest(ma3, bylab = "")                           # forest plot




########        Meta-regression        ########
#################################################


# perform meta-regression of meta object ma3 
mr1 = metareg(ma3)
mr1

# or do it by stating the covariate 'alloc' using "ma1"
mr1 = metareg(ma1, alloc)


# extract coefficients of the meta-regression:
coef(mr1)

# Odds ratio for the non-random allocation subgroup:
logOR.nra = coef(mr1)[1]        # store coefficient of non-random allocation group
round(exp(logOR.nra), 2)        # exponentiate to see the odds ratio


# Odds ratio for the random allocation subgroup:
logOR.ra = sum(coef(mr1))       # store coefficient of random allocation group
round(exp(logOR.ra), 2)         # exponentiate to see the odds ratio



# Meta-regression with covariate latitude
mr2 = metareg(ma1, latitude)
mr2

# produce bubble plot
bubble(mr2, col.line = "blue")



# Meta-regression with covariate startyr (year the study started)
mr3 = metareg(ma1, startyr)
mr3








########        Dataset magnes        ########
##############################################

# Load dataset "magnes" and store it as dataframe object called "Magnesium"
Magnesium = read_excel("magnes.xls")


# Perform meta-analysis on studies performed up to and including 1991
OR1 = metabin( deaths1, pop1, deaths0, pop0, data = Magnesium, 
               studlab = trialnam, sm = "OR", subset = year<=1991)
summary(OR1)


# Perform meta-analysis on all studies except for ISIS-4
OR2 <- update(OR1, subset = trialnam!="ISIS-4")     # update previous meta-analysis by changing the subset 
summary(OR2)


# Perform meta-analysis including all trials
ORall = metabin(deaths1, pop1, deaths0, pop0, data = Magnesium, 
                studlab = trialnam, sm = "OR")
summary(ORall)




########        Funnel plots        ########
############################################

# funnel plot for all studies
funnel(ORall)

# funnel plot exclusing study ISIS-4
funnel(OR2)




# produce Harbord's score-based test for funnel plot asymmetry including all studies
metabias(ORall, method.bias = "score")

# produce Harbord's score-based test for funnel plot asymmetry excluding study ISIS-4
metabias(OR2, method.bias = "score")

